@@ -12,7 +12,7 @@ from .pickle_signer import PickleSigner  # nosec
 
 
 def dump(obj, file=None):
-    return PickleSigner().dump(obj, file)
+    return PickleSigner(use_header=False).dump(obj, file)
 
 
 def load(file):
@@ -29,7 +29,7 @@ def save_resource(obj, package: Package, resource: Resource):
         return dump(obj, file)
 
 
-__version__: str = "0.1.0"
+__version__: str = "1.0.0"
 
 __all__ = [
     "dump",
